
import React, { useEffect, useState } from 'react';
import Page from '../../components/Page/index';
import { Form, Typography, Space, Tooltip } from 'antd';
import { FolderFilled } from '@ant-design/icons';
import * as $$ from '../../utils/utility';
import { useLocation, useNavigate } from 'react-router-dom';
import TableView from '../../components/TableView';
import NewTableSearch from '../../components/NewTableSearch';
import MyTabs from '../../components/MyTabs';

const { Link } = Typography;

// 获取数据
function getMyMediationDataApi(submitData) {
  return $$.ax.request({ url: 'caseTask/pageMyMediate', type: 'get', data: submitData, service: 'mediate' });
}

function getCacheLatjCaseGuideApi(submitData) {
  return $$.ax.request({ url: 'guide/cacheLatjCaseGuide', type: 'get', data: submitData, service: 'mediate' });
}


function getCacheOpenAiCaseGuideApi(submitData) {
  return $$.ax.request({ url: 'guide/cacheOpenAiCaseGuideList', type: 'get', data: submitData, service: 'mediate' });
}


const Comprehensive = () => {
  const [form] = Form.useForm();

  let location = useLocation();

  let navigate = useNavigate();

  // 搜索
  const [search, setSearch] = useState({ page: 1, size: 10, pageType: '1', joinRole: '1' });

  // 数据
  const [data, setData] = useState({ tableData: [] });

  // 表头
  const columns = () => {
    const columnOne =
      search.pageType === '3'
        ? [
          {
            title: '调解结果',
            dataIndex: 'mediResultName',
            record: (text, record) =>
              !text ? '-' : <div className={`public-tag public-tag-${record.mediResult === '22_00025-1' ? 'tagGreen' : 'tagRed'}`}>{text}</div>,
          },
        ]
        : [];
    const columnTwo =
      search.pageType === '3'
        ? [{ title: '调解结束时间', dataIndex: 'mediEndTime' }]
        : [
          // TODO:暂时取消，后续可根据需求改动
          // {
          // 	title: '处理时限',
          // 	dataIndex: 'expireTime',
          // 	render: (text, record) => {
          // 		let obj = $$.getHours(text);
          // 		return record.status === '1' ? (
          // 			<span className={obj.isNegativeNum ? 'tableView-dangerTime' : ''}>{!!text ? `${obj.hours}小时` : '-'}</span>
          // 		) : (
          // 			'-'
          // 		);
          // 	},
          // },
        ];
    const columnThree = search.joinRole === '2' ? [{ title: '调解员', dataIndex: 'mediator' }] : [];
    const columnsData = [
      {
        title: '调解案号',
        dataIndex: 'caseNo',
        render: (text, record) => (
          <Space size={0}>
            {record.taskType === '2' && <div className="myMediation-tuiTag">退</div>}
            {record.serieStatus === '2' ? (
              <Space size={4}>
                <FolderFilled className="public-folder" />
                <span>系列案</span>
              </Space>
            ) : (
              <Tooltip placement="topLeft" title={text}>
                {text}
              </Tooltip>
            )}
          </Space>
        ),
      },
      { title: '调解进度', dataIndex: 'processName' },
      ...columnOne,
      { title: '申请人', dataIndex: 'plaintiffs' },
      { title: '被申请人', dataIndex: 'defendants' },
      { title: '纠纷发生地', dataIndex: 'addr' },
      { title: '调解类型', dataIndex: 'mediTypeName' },
      { title: '纠纷类型', dataIndex: 'caseTypeName' },
      { title: '申请渠道', dataIndex: 'canalName' },
      { title: '纠纷受理时间', dataIndex: 'acceptTime' },
      ...columnTwo,
      ...columnThree,
      { title: '协助调解员', width: 100, dataIndex: 'otherMediator' },
      {
        title: '操作',
        dataIndex: 'action',
        width: 50,
        render: (_, record) => {
          let type = 'check';
          if (search.joinRole === '2') {
            type = 'check'
          } else if (search.joinRole === '1') {
            if (search.pageType == '3') {
              type = 'check';
            } else {
              type = 'handle'
            }
          }
          // if (search.joinRole === '1' && (search.pageType === '1' || search.pageType === '2')) {
          //   type = 'handle';
          // }
          // if (search.joinRole === '2' && (search.pageType === '1' || search.pageType === '2')) {
          //   type = 'feedback';
          // }
          // if (search.joinRole === '2' && search.pageType === '3' && record.feedbackStatus === '1') {
          //   type = 'feedback';
          // }
          return <Link onClick={() => handleJump(type, record)}>{type === 'check' ? '查看' : '调解'}</Link>;
        },
      },
    ];
    return columnsData;
  };

  // 跳转详情页
  function handleJump(type, info) {
    if (type === 'feedback') {
      // 协助反馈
      $$.setSessionStorage(location.pathname, {
        search,
        breadcrumbData: [{ title: '我的调解', url: '/mediate/myAdjust' }, { title: '我协助的' }],
        title: info.caseNo,
        tableActive: info.id,
        tabs: [{ label: '调解', key: 'feedBack' }],
        pageFrom: 'myMediationFeedBack',
      });
      navigate(`/mediate/caseDetail?caseId=${info.id}&taskId=${info.taskId}&back=${location.pathname}`);
    }
    // 查看
    if (type === 'check') {
      $$.setSessionStorage(location.pathname, {
        search,
        breadcrumbData: [{ title: '我的调解', url: '/mediate/myAdjust' }, { title: '查看' }],
        title: info.caseNo,
        tableActive: info.id,
        pageFrom: 'myMediation',
      });
      navigate(`/mediate/caseDetail?caseId=${info.id}&taskId=${info.taskId}&back=${location.pathname}`);
    }
    // 调解
    if (type === 'handle') {

      // getCacheOpenAiCaseGuide({ caseId: info.id, guideType: 3 })

      // getCacheLatjCaseGuide({ caseId: info.id })
      if (info.serieStatus === '2') {
        // 系列案
        $$.setSessionStorage(location.pathname, {
          search,
          breadcrumbData: [{ title: '我的调解', url: '/mediate/myAdjust' }, { title: '我负责的' }],
          title: info.caseNo,
          tableActive: info.id,
          tabs: [{ label: '调解', key: 'caseFolderFeedBack' }],
          pageFrom: 'myMediationCaseFolderFeedBack',
        });
        navigate(`/mediate/caseDetail?caseId=${info.id}&taskId=${info.taskId}&back=${location.pathname}`);
      } else {
        // 非系列案
        $$.setSessionStorage(location.pathname, {
          search,
          tableActive: info.id,
        });
        navigate(`/mediate/myAdjust/mediationWindow?caseId=${info.id}&taskId=${info.taskId}&taskType=${info.taskType}&back=${location.pathname}`);
      }
    }
  }

  // 页码修改
  function handleChangePage(page, pageSize) {
    let paramsObj = Object.assign(search, { page, size: pageSize });
    setSearch(paramsObj);
    getMyMediationData(paramsObj);
  }

  // 搜索 or 重置
  function handleSearch(type, session) {
    let paramsObj = {};
    if (type === 'search') {
      paramsObj = { ...search, ...form.getFieldsValue(), page: 1 };
      $$.changeTimeFormat(paramsObj, 'acceptTime', 'acceptStart', 'acceptEnd');
      $$.changeTimeFormat(paramsObj, 'mediEndTime', 'mediEndTimeStart', 'mediEndTimeEnd');
      $$.changeTimeFormat(paramsObj, 'mediStartTime', 'mediStartTimeStart', 'mediStartTimeEnd');
    }
    if (type === 'reset') {
      paramsObj = { page: 1, size: 10, pageType: '1', joinRole: '1' };
      form.resetFields();
      form.setFieldsValue({ joinRole: '1' });
    }
    if (type === 'recurrent') {
      paramsObj = { ...search, ...session.search };
      let copyObj = { ...paramsObj };
      if (copyObj.acceptStart) {
        copyObj.acceptTime = [$$.myMoment(copyObj.acceptStart), $$.myMoment(copyObj.acceptEnd)];
      }
      if (copyObj.mediEndTimeStart) {
        copyObj.mediEndTime = [$$.myMoment(copyObj.mediEndTimeStart), $$.myMoment(copyObj.mediEndTimeEnd)];
      }
      if (copyObj.mediStartTimeStart) {
        copyObj.mediStartTime = [$$.myMoment(copyObj.mediStartTimeStart), $$.myMoment(copyObj.mediStartTimeEnd)];
      }
      form.setFieldsValue(copyObj);
    }
    getMyMediationData(paramsObj, session?.tableActive);
  }

  // 获取数据
  async function getMyMediationData(submitData, tableActive) {
    global.setSpinning(true);
    const res = await getMyMediationDataApi(submitData);
    global.setSpinning(false);
    if (res.type) {
      setSearch(submitData);
      setData({
        total: res.data?.dtoPage?.totalElements,
        tableData: res.data?.dtoPage?.content || [],
        tableActive,
        countDtj: res.data.countDtj,
        countTjz: res.data.countTjz,
        countTjjs: res.data.countTjjs,
      });
    }
  }

  // 初始化
  useEffect(() => {
    let type = false;
    let values = $$.getSessionStorage(location.pathname);
    type = $$.getQueryString('isBack') && !!values;
    type ? handleSearch('recurrent', values) : handleSearch('reset');
    if (!!values) {
      $$.clearSessionStorage(location.pathname);
    }
  }, []);

  const countDtj = (search.pageType === '1' ? data.total : data.countDtj) || 0;

  const countTjz = (search.pageType === '2' ? data.total : data.countTjz) || 0;

  const countTjjs = (search.pageType === '3' ? data.total : data.countTjjs) || 0;

  return (
    <Page pageHead={{ title: '综合查询', subtitle: '管理员名下综合查询列表' }}>
      <div className="myMediation">
        <div className="myMediation-search">
          <NewTableSearch
            labelLength={6}
            form={form}
            itemData={[
              { type: 'RangePicker', name: 'acceptTime', label: '办结时间' },
              { type: 'RangePicker', name: 'acceptTime', label: '归档时间' },
              { type: 'Input', name: 'defendants', label: '被申请人' },
              { type: 'Input', name: 'caseNo', label: '调解案号' },
              { type: 'Input', name: 'addr', label: '纠纷发生地' },
              {
                type: 'Select',
                name: 'joinRole',
                label: '参与角色',
                selectdata: [
                  { label: '我负责的', value: '1' },
                  { label: '我协助的', value: '2' },
                ],
              },
              { type: 'RangePicker', name: 'mediStartTime', label: '调解开始时间' },
              { type: 'RangePicker', name: 'mediEndTime', label: '调解结束时间' },
              { type: 'Select', name: 'mediResult', label: '调解结果', selectdata: $$.options.mediResult },
            ]}
            handleReset={() => handleSearch('reset')}
            handleSearch={() => handleSearch('search')}
          />
        </div>
        <div className="pageTabs">
          <MyTabs
            tabs={[
              { key: '1', label: `待调解(${$$.showMoreNum(countDtj)})` },
              { key: '2', label: `调解中(${$$.showMoreNum(countTjz)})` },
              { key: '3', label: `调解结束(${$$.showMoreNum(countTjjs)})` },
            ]}
            activeKey={search.pageType}
            onChange={(activeKey) => getMyMediationData({ ...search, page: 1, size: 10, pageType: activeKey })}
          />
        </div>
        <div className="pageTable">
          <TableView
            showHeader
            title="查询结果"
            columns={columns()}
            dataSource={data.tableData}
            pagination={{
              current: search.page,
              pageSize: search.size,
              total: data.total,
              onChange: (page, pageSize) => handleChangePage(page, pageSize),
            }}
            rowClassName={(record) => (record.id === data.tableActive ? 'tableRowActive' : '')}
          />
        </div>
      </div>
    </Page>
  );
};

export default Comprehensive;
